## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
library(chattr)

chattr_use("ollama")

chattr_defaults()

## -----------------------------------------------------------------------------
my_list <- function() {
  return(ls(pattern = "x", envir = globalenv()))
}

## -----------------------------------------------------------------------------
chattr_defaults(prompt = "{ my_list() }")

## -----------------------------------------------------------------------------
x1 <- 1
x2 <- 2

## -----------------------------------------------------------------------------
chattr(preview = TRUE)

## -----------------------------------------------------------------------------
x3 <- 3

chattr(preview = TRUE)

